@@ -25,18 +25,26 @@ codes::codes(int v)
       "74781","74789","9960","9961","99661","99662","V421","V422","V432","V433","V450","V4581",
       "V533"};
 
-    dx_fixed_cvd = {"416"};
+    dx_fixed_cvd = {"416",
+      "99683" // transplant too
+    };
 
     dx_respiratory = {"32725","4160","4162","51630","51631","51637","51884","5190","2770","748","7704","V426",
       "V440","V4576","V460","V461","V550"};
 
-    dx_fixed_respiratory = {"5163"};
+    dx_fixed_respiratory = {"5163",
+      "99684" // transplant too
+    };
 
-    dx_renal = {"34461","585","5964","59653","59654","753","99668","V420","V445","V446",
+    dx_renal = {"34461","585","5964","59653","59654","753","99668",
+      "99681", //transplant
+      "V420","V445","V446",
       "V451","V4573","V4574","V536","V555","V556","V56"};
 
     dx_gi = {"4530","5364","555","556","5571","5602","5647","5714","5715","5716","5717",
-      "5718","5719","7503","751","V427","V4283","V4284","V441","V442","V443","V444","V5350",
+      "5718","5719","7503","751",
+      "99682", "99686", "99687", // transplant
+      "V427","V4283","V4284","V441","V442","V443","V444","V5350",
       "V5351","V5359","V551","V552","V553","V554"};
 
     dx_hemato_immu = {"042","043","044","135","279","2820","2821","2822","2823","2824","2825",
@@ -119,13 +127,32 @@ codes::codes(int v)
       "G119","G120","G121","G122","G128","G129","G3101","G3109","G318","G3289","G71",
       "G72","G800","G803","G804","G808","G901","G938","G939","G94","Q00","Q01","Q02","Q03","Q04","Q05","Q06","Q07",
       "G911","G319","G253","G9519","G9589","G909","G40311","G40301","G40211","G40219","G40411",
-      "G40419","G40804","G40111","G40119","G40911","G40919","G371","G372","G378","G8190","G8290",
+      "G40419","G40804","G40111","G40119","G40911","G40919","G371","G372","G378","G8190",
       "G8250","G8251","G8252","G8253","G8254","G835","G839","G931","G935","I6330","I6350","G10",
       "G20","G210","G2111","G2119","G218","G230","G231","G232","G238","G2402","G248",
       "G254","G255","G2581","G2582","G2583","G2589","G259","R403","G9782","T8509XA",
       "T85190A","T85192A","T85199A","T8579XA","Z982","Z4541","Z4542", "Q851"};
 
     dx_fixed_neuromusc = {"G80"};
+    // NOTE: G80 and G80.3 are listed in pccc/inst/pccc_references/Categories_of_CCCv2_and_Corresponding_ICD.docx
+    // However, it appears that during some dev work the following was
+    // determined for PCCC V2
+    // G80.0 -- include
+    // G80.1 -- include
+    // G80.2 -- exclude
+    // G80.3 -- include
+    // G80.4 -- include
+    // G80.5 -- (not a valid ICD code)
+    // G80.6 -- (not a valid ICD code)
+    // G80.7 -- (not a valid ICD code)
+    // G80.8 -- include
+    // G80.9 -- exclude
+    //
+    // For version 3, all the G80.x codes will be included
+    // See Supplement 3 from
+    // Feinstein JA, Hall M, Davidson A, Feudtner C. Pediatric Complex Chronic
+    // Condition System Version 3. JAMA Netw Open. 2024;7(7):e2420579.
+    // doi:10.1001/jamanetworkopen.2024.20579
 
     dx_cvd = {"I270","I271","I272","I2781","I2789","I279","I340","I348","I360","I368","I370",
       "I378","I42","I43","I44","I45","I47","I48","I490","I491","I493","I494","I495","I498","I499",
@@ -134,6 +161,7 @@ codes::codes(int v)
       "Z951","T82519A","T82529A","T82539A","T82599A","T82110A","T82111A","T82120A","T82121A",
       "T82190A","T82191A","T8201XA","T8202XA","T8203XA","T8209XA","T82211A","T82212A","T82213A",
       "T82218A","T82221A","T82222A","T82223A","T82228A","T82518A","T82528A","T82538A","T82598A",
+      "T8620", "T8621", "T8622",
       "T826XXA","T827XXA","Z941","Z950","Z952","Z95810","Z95811","Z95812","Z95818","Z953","Z45010",
       "Z45018","Z4502","Z4509","Z959"};
 
@@ -142,7 +170,7 @@ codes::codes(int v)
       "Z9911","Z9912","T86810","T86811","T86819"};
 
     dx_renal = {"N18","Q60","Q61","Q62","Q63","Q64","Z905","Z906","G834","N312","N319","T8571XA",
-      "Z940","Z9350","Z9351","Z9352","Z9359","Z936","Z9115","Z992","Z435","Z436","Z446","Z4901",
+      "Z940","Z9350","Z9351","Z9352","Z9359","Z936","Z9115","Z992","Z435","Z436","Z466","Z4901",
       "Z4902","Z4931","Z4932","T8610","T8611","T8612"};
 
     dx_gi = {"K50","K51","K73","K74","K754","K760","K761","K762","K763","K768","Q390","Q391",
@@ -152,7 +180,7 @@ codes::codes(int v)
       "T86899","T86850","T86851","T86859"};
 
     dx_hemato_immu = {"B20", "D55","D56","D57","D58","D60","D61","D71","D720","D80","D81","D82",
-      "D83","D84","D85","D87","D88","D86","M303","M359","B21","B22","B23","B24","D700","D704",
+      "D83","D84","D86","M303","M359","B21","B22","B23","B24","D700","D704",
       "D66", "D682","D6941","D6942","D761","D762","D763","M300","M310","M311","M3130","M314",
       "M316","M3210","M3390","M340","M341","M349","Z21"};
 
@@ -163,29 +191,29 @@ codes::codes(int v)
       "E830","E831","E833","E834","E88","H498","E85","E009","E230","E232","E222","E233","E237",
       "E240","E242","E243","E248","E249","E2681","E250","E258","E259","Z4681","Z794","Z9641"};
 
-    dx_congeni_genetic = {"E343","K449","M410","M412","M4130","M418","M419","M4330","M965","Q722","Q750",
+    dx_congeni_genetic = {"E343","K449","M410","M412","M4130","M418","M419","M433","M965","Q722","Q750",
       "Q752","Q759","Q760","Q761","Q762","Q764","Q765","Q766","Q767","Q77","Q780","Q781","Q782",
       "Q783","Q784","Q788","Q789","Q790","Q791","Q792","Q793","Q794","Q799","Q795","Q8740","Q8781",
       "Q8789","Q897","Q899","Q909","Q913","Q914","Q917","Q928","Q93","Q950","Q969","Q97","Q98",
       "Q992","Q998","Q999","Q898","Q81"};
 
-    dx_malignancy = {"C","D00","D01","D02","D03","D04","D05","D06","D07","D08","D09","D37","D38",
+    dx_malignancy = {"C","D00","D01","D02","D03","D04","D05","D06","D07","D09","D37","D38",
       "D39","D3A0","D40","D41","D42","D43","D44","D45","D46","D47","D48","D49","Q850","Z9481",
       "Z9484","T8600","T8601","T8602","T8609"};
 
     dx_neonatal = {"P0501","P0511","P0502","P0512","P052","P059","P0701","P0702","P0721","P0722",
       "P0723","P0724","P0725","P100","P101","P104","P524","P528","P115","P84","P916","P210","P250",
-      "P251","P253","P258","P219","P270","P271","P278","P350","P351","P2521","P2522","P560","P570",
+      "P251","P252","P253","P258","P219","P270","P271","P278","P350","P351","P560","P570",
       "P578","P613","P614","P773","P832","P912"};
 
-    dx_tech_dep = {"T8509XA","T85190A","T85192A","T85199A","T8579XA","Z982","Z45441","Z45442","T82519A",
+    dx_tech_dep = {"T8509XA","T85190A","T85192A","T85199A","T8579XA","Z982","Z4541","Z4542","T82519A",
       "T82529A","T82539A","T82599A","T82110A","T82111A","T82120A","T82121A","T82190A","T82191A",
       "T8201XA","T8202XA","T8203XA","T8209XA","T82211A","T82212A","T82213A","T82218A","T82221A",
       "T82222A","T82223A","T82228A","T82518A","T82528A","T82538A","T82598A","T826XXA","T827XXA",
       "Z950","Z952","Z953","Z95810","Z95811","Z95812","Z95818","Z45010","Z45018","Z4502","Z4509",
       "Z959","J9500","J9501","J9502","J9503","J9504","J9509","Z430","Z930","Z942","Z990","J95850",
       "Z9911","Z9912","T8571XA","Z940","Z9350","Z9351","Z9352","Z9359","Z936","Z9115","Z992",
-      "Z435","Z436","Z446","K9420","K9422","K9423","K9429","Z931","Z932","Z933","Z934","Z431",
+      "Z435","Z436","Z466","K9420","K9422","K9423","K9429","Z931","Z932","Z933","Z934","Z431",
       "Z432","Z433","Z434","Z4651","Z4659","Z4681","Z9641","T84019A","T84029A","T84039A","T84049A",
       "T84059A","T84069A","T84099A","T84498A","T84119A","T84129A","T84199A","T8450XA",
       "T8460XA","T847XXA","T8690","T8691","T8692","T8699","T8610","T8611","T8612","T8640","T8641",
@@ -195,7 +223,7 @@ codes::codes(int v)
 
     dx_transplant = {"T8600","T8601","T8602","T8609","T8610","T8611","T8612","T8620","T8621","T8622",
       "T86810","T86811","T86819","T8640","T8641","T8642","T86890","T86891","T86899","T86850",
-      "T86851","T86859","T865","T8690","T8691","T8692","T8699"};
+      "T86851","T86859","T865","T8690","T8691","T8692","T8699","Z940"};
 
     pc_neuromusc = {"0016070","0016071","0016072","0016073","0016074","0016075","0016076","0016077",
       "0016078","001607B","00160J0","00160J1","00160J2","00160J4","00160J5","00160J6","00160J7",
